@@ -24,20 +24,30 @@ echo "*** Setting up users and groups"
 
 if [ ! -z "${AFP_USER}" ]; then
     if [ ! -z "${AFP_UID}" ]; then
-        cmd="$cmd --uid ${AFP_UID}"
+        uidcmd="-u ${AFP_UID}"
     fi
     if [ ! -z "${AFP_GID}" ]; then
-        cmd="$cmd --gid ${AFP_GID}"
-        groupadd --gid ${AFP_GID} ${AFP_USER} || true 2> /dev/null
+        gidcmd="-g ${AFP_GID}"
     fi
-    adduser $cmd --no-create-home --disabled-password --gecos '' "${AFP_USER}" || true 2> /dev/null
     if [ ! -z "${AFP_GROUP}" ]; then
-        groupadd ${AFP_GROUP} || true 2> /dev/null
-        usermod -aG "${AFP_GROUP}" "${AFP_USER}" || true 2> /dev/null
+        groupcmd="-G ${AFP_GROUP}"
+        addgroup ${gidcmd} ${AFP_GROUP} || true 2> /dev/null
     fi
-    if [ ! -z "${AFP_PASS}" ]; then
-        echo "${AFP_USER}:${AFP_PASS}" | chpasswd
+    adduser ${uidcmd} ${groupcmd} --no-create-home --disabled-password "${AFP_USER}" || true 2> /dev/null
+
+    echo "${AFP_USER}:${AFP_PASS}" | chpasswd
+
+    # Creating credentials for the RandNum UAM
+    set +e
+    if [ -f "/usr/local/etc/netatalk/afppasswd" ]; then
+    	rm -f /usr/local/etc/netatalk/afppasswd
     fi
+    afppasswd -c
+    afppasswd -a -f -w "${AFP_PASS}" "${AFP_USER}"
+    if [ $? -ne 0 ]; then
+        echo "NOTE: Use a password of 8 chars or less to authenticate with Mac OS 8 or earlier clients"
+    fi
+    set -e
 fi
 
 echo "*** Configuring shared volume"
@@ -72,11 +82,12 @@ fi
 
 if [ -z "${MANUAL_CONFIG}" ]; then
     echo "*** Configuring Netatalk"
-    cat <<EOF > /usr/etc/afp.conf
+    cat <<EOF > /usr/local/etc/afp.conf
 [Global]
 log file = /var/log/afpd.log
 log level = default:${AFP_LOGLEVEL:-info}
 spotlight = yes
+uam list = uams_dhx2.so uams_dhx.so uams_randnum.so
 zeroconf name = ${SERVER_NAME:-Netatalk File Server}
 [${SHARE_NAME:-File Sharing}]
 path = /mnt/afpshare
