@@ -9,30 +9,29 @@
 #endif /* HAVE_CONFIG_H */
 
 #if defined (USE_PAM) && defined (UAM_DHX2)
+
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <atalk/logger.h>
-
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif /* HAVE_UNISTD_H */
-#include <errno.h>
+
 #ifdef HAVE_SECURITY_PAM_APPL_H
 #include <security/pam_appl.h>
 #endif
+
 #ifdef HAVE_PAM_PAM_APPL_H
 #include <pam/pam_appl.h>
 #endif
 
-
 #ifdef HAVE_LIBGCRYPT
 #include <gcrypt.h>
 #endif /* HAVE_LIBGCRYPT */
 
 #include <atalk/afp.h>
-#include <atalk/uam.h>
 #include <atalk/globals.h>
+#include <atalk/logger.h>
+#include <atalk/uam.h>
 
 /* Number of bits for p which we generate. Everybode out there uses 512, so we beet them */
 #define PRIMEBITS 1024
@@ -136,7 +135,7 @@ error:
  * echo off means password.
  */
 static int PAM_conv (int num_msg,
-#ifdef LINUX
+#if !defined(__svr4__)
                      const struct pam_message **msg,
 #else
                      struct pam_message **msg,
