@@ -1,7 +1,7 @@
 /*
  *
  * Copyright (c) 1990,1993 Regents of The University of Michigan.
- * Copyright (c) 1999 Adrian Sun (asun@u.washington.edu) 
+ * Copyright (c) 1999 Adrian Sun (asun@u.washington.edu)
  * All Rights Reserved.  See COPYRIGHT.
  */
 
@@ -10,39 +10,41 @@
 #endif /* HAVE_CONFIG_H */
 
 #if defined(USE_PAM) && defined(UAM_DHX)
+
+#include <arpa/inet.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <atalk/logger.h>
-
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif /* HAVE_UNISTD_H */
-#include <errno.h>
-#ifdef HAVE_SECURITY_PAM_APPL_H
-#include <security/pam_appl.h>
-#endif
+
 #ifdef HAVE_PAM_PAM_APPL_H
 #include <pam/pam_appl.h>
 #endif
-#include <arpa/inet.h>
 
-#if defined(GNUTLS_DHX)
-#include <gnutls/openssl.h>
+#ifdef HAVE_SECURITY_PAM_APPL_H
+#include <security/pam_appl.h>
+#endif
+
+#if defined(EMBEDDED_SSL) || defined(WOLFSSL_DHX)
+#if defined(WOLFSSL_DHX)
+#include <wolfssl/options.h>
+#endif
+#include <openssl/cast.h>
+#include <wolfssl/openssl/bn.h>
+#include <wolfssl/openssl/dh.h>
+#include <wolfssl/openssl/err.h>
+#include <wolfssl/openssl/ssl.h>
 #elif defined(OPENSSL_DHX)
 #include <openssl/bn.h>
 #include <openssl/dh.h>
 #include <openssl/cast.h>
 #include <openssl/err.h>
 #include "openssl_compat.h"
-#else /* OPENSSL_DHX */
-#include <bn.h>
-#include <dh.h>
-#include <cast.h>
-#include <err.h>
-#endif /* OPENSSL_DHX */
+#endif /* EMBEDDED_SSL */
 
 #include <atalk/afp.h>
+#include <atalk/logger.h>
 #include <atalk/uam.h>
 
 #define KEYSIZE 16
@@ -71,16 +73,16 @@ static const uint8_t g = 0x07;
 /* Static variables used to communicate between the conversation function
  * and the server_login function
  */
-static pam_handle_t *pamh = NULL; 
-static char *PAM_username;
-static char *PAM_password;
+static pam_handle_t *pamh = NULL;
+static unsigned char *PAM_username;
+static unsigned char *PAM_password;
 
 /* PAM conversation function
  * Here we assume (for now, at least) that echo on means login name, and
  * echo off means password.
  */
 static int PAM_conv (int num_msg,
-#ifdef LINUX
+#if !defined(__svr4__)
                      const struct pam_message **msg,
 #else
                      struct pam_message **msg,
@@ -89,9 +91,9 @@ static int PAM_conv (int num_msg,
                      void *appdata_ptr _U_) {
   int count = 0;
   struct pam_response *reply;
-  
+
 #define COPY_STRING(s) (s) ? strdup(s) : NULL
-  
+
   errno = 0;
 
   if (num_msg < 1) {
@@ -102,7 +104,7 @@ static int PAM_conv (int num_msg,
     return PAM_CONV_ERR;
   }
 
-  reply = (struct pam_response *) 
+  reply = (struct pam_response *)
     calloc(num_msg, sizeof(struct pam_response));
 
   if (!reply) {
@@ -118,7 +120,7 @@ static int PAM_conv (int num_msg,
 
     switch (msg[count]->msg_style) {
     case PAM_PROMPT_ECHO_ON:
-      if (!(string = COPY_STRING(PAM_username))) {
+      if (!(string = COPY_STRING((const char *)PAM_username))) {
     /* Log Entry */
            LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM: username failure -- %s",
 		  strerror(errno));
@@ -127,7 +129,7 @@ static int PAM_conv (int num_msg,
       }
       break;
     case PAM_PROMPT_ECHO_OFF:
-      if (!(string = COPY_STRING(PAM_password))) {
+      if (!(string = COPY_STRING((const char *)PAM_password))) {
     /* Log Entry */
            LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM: passwd failure: --: %s",
 		  strerror(errno));
@@ -150,7 +152,7 @@ static int PAM_conv (int num_msg,
       goto pam_fail_conv;
     }
 
-    if (string) {  
+    if (string) {
       reply[count].resp_retcode = 0;
       reply[count].resp = string;
       string = NULL;
@@ -171,7 +173,7 @@ pam_fail_conv:
     case PAM_PROMPT_ECHO_OFF:
     case PAM_PROMPT_ECHO_ON:
       free(reply[count].resp);
-      break;      
+      break;
     }
   }
   free(reply);
@@ -188,8 +190,8 @@ static struct pam_conv PAM_conversation = {
 };
 
 
-static int dhx_setup(void *obj, char *ibuf, size_t ibuflen _U_, 
-		     char *rbuf, size_t *rbuflen)
+static int dhx_setup(void *obj, const unsigned char *ibuf, size_t ibuflen _U_,
+		     unsigned char *rbuf, size_t *rbuflen)
 {
     uint16_t sessid;
     size_t i;
@@ -198,7 +200,7 @@ static int dhx_setup(void *obj, char *ibuf, size_t ibuflen _U_,
     DH *dh;
 
     /* get the client's public key */
-    if (!(bn = BN_bin2bn((unsigned char *)ibuf, KEYSIZE, NULL))) {
+    if (!(bn = BN_bin2bn(ibuf, KEYSIZE, NULL))) {
     /* Log Entry */
            LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM No Public Key -- %s",
 		  strerror(errno));
@@ -268,19 +270,19 @@ static int dhx_setup(void *obj, char *ibuf, size_t ibuflen _U_,
     }
 
     /* figure out the key. store the key in rbuf for now. */
-    i = DH_compute_key((unsigned char *)rbuf, bn, dh);
-    
+    i = (unsigned long) DH_compute_key(rbuf, bn, dh);
+
     /* set the key */
-    CAST_set_key(&castkey, i, (unsigned char *)rbuf);
-    
+    CAST_set_key(&castkey, (int) i, rbuf);
+
     /* session id. it's just a hashed version of the object pointer. */
     sessid = dhxhash(obj);
     memcpy(rbuf, &sessid, sizeof(sessid));
     rbuf += sizeof(sessid);
     *rbuflen += sizeof(sessid);
-    
+
     /* public key */
-    BN_bn2bin(pub_key, (unsigned char *)rbuf);
+    BN_bn2bin(pub_key, rbuf);
     rbuf += KEYSIZE;
     *rbuflen += KEYSIZE;
 
@@ -294,12 +296,12 @@ static int dhx_setup(void *obj, char *ibuf, size_t ibuflen _U_,
 		  strerror(errno));
     /* Log Entry */
       goto pam_fail;
-    }    
+    }
     memcpy(rbuf, &randbuf, sizeof(randbuf));
 
     /* get the signature. it's always 16 bytes. */
 #if 0
-    if (uam_afpserver_option(obj, UAM_OPTION_SIGNATURE, 
+    if (uam_afpserver_option(obj, UAM_OPTION_SIGNATURE,
 			     (void *) &buf, NULL) < 0) {
       *rbuflen = 0;
     /* Log Entry */
@@ -308,13 +310,13 @@ static int dhx_setup(void *obj, char *ibuf, size_t ibuflen _U_,
     /* Log Entry */
       goto pam_fail;
     }
-    memcpy(rbuf + KEYSIZE, buf, KEYSIZE); 
+    memcpy(rbuf + KEYSIZE, buf, KEYSIZE);
 #else /* 0 */
-    memset(rbuf + KEYSIZE, 0, KEYSIZE); 
+    memset(rbuf + KEYSIZE, 0, KEYSIZE);
 #endif /* 0 */
 
     /* encrypt using cast */
-    CAST_cbc_encrypt((unsigned char *)rbuf, (unsigned char *)rbuf, CRYPTBUFLEN, &castkey, msg2_iv, 
+    CAST_cbc_encrypt(rbuf, rbuf, CRYPTBUFLEN, &castkey, msg2_iv,
 		     CAST_ENCRYPT);
     *rbuflen += CRYPTBUFLEN;
     BN_free(bn);
@@ -332,11 +334,11 @@ pam_fail:
 }
 
 /* -------------------------------- */
-static int login(void *obj, char *username, int ulen,  struct passwd **uam_pwd _U_,
-		     char *ibuf, size_t ibuflen,
-		     char *rbuf, size_t *rbuflen)
+static int login(void *obj, unsigned char *username, int ulen,
+	struct passwd **uam_pwd _U_, const unsigned char *ibuf, size_t ibuflen,
+	unsigned char *rbuf, size_t *rbuflen)
 {
-    if (( dhxpwd = uam_getname(obj, username, ulen)) == NULL ) {
+    if (( dhxpwd = uam_getname(obj, (char *)username, ulen)) == NULL ) {
         LOG(log_info, logtype_uams, "uams_dhx_pam.c: unknown username [%s]", username);
         return AFPERR_NOTAUTH;
     }
@@ -350,10 +352,10 @@ static int login(void *obj, char *username, int ulen,  struct passwd **uam_pwd _
 /* dhx login: things are done in a slightly bizarre order to avoid
  * having to clean things up if there's an error. */
 static int pam_login(void *obj, struct passwd **uam_pwd,
-		     char *ibuf, size_t ibuflen,
-		     char *rbuf, size_t *rbuflen)
+		     unsigned char *ibuf, size_t ibuflen,
+		     unsigned char *rbuf, size_t *rbuflen)
 {
-    char *username;
+    unsigned char *username;
     size_t len, ulen;
 
     *rbuflen = 0;
@@ -365,7 +367,7 @@ static int pam_login(void *obj, struct passwd **uam_pwd,
         return AFPERR_PARAM;
     }
 
-    len = (unsigned char) *ibuf++;
+    len = *ibuf++;
     if ( len > ulen ) {
         LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM: Signature Retieval Failure -- %s",
 		  strerror(errno));
@@ -384,13 +386,13 @@ static int pam_login(void *obj, struct passwd **uam_pwd,
 
 /* ----------------------------- */
 static int pam_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
-		     char *ibuf, size_t ibuflen,
-		     char *rbuf, size_t *rbuflen)
+		     const unsigned char *ibuf, size_t ibuflen,
+		     unsigned char *rbuf, size_t *rbuflen)
 {
-    char *username;
+    unsigned char *username;
     int len;
     size_t ulen;
-    uint16_t  temp16;
+    uint16_t temp16;
 
     *rbuflen = 0;
 
@@ -421,8 +423,8 @@ static int pam_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
 /* -------------------------------- */
 
 static int pam_logincont(void *obj, struct passwd **uam_pwd,
-			 char *ibuf, size_t ibuflen _U_, 
-			 char *rbuf, size_t *rbuflen)
+			 const unsigned char *ibuf, size_t ibuflen _U_,
+			 unsigned char *rbuf, size_t *rbuflen)
 {
     const char *hostname;
     BIGNUM *bn1, *bn2, *bn3;
@@ -441,7 +443,7 @@ static int pam_logincont(void *obj, struct passwd **uam_pwd,
       return AFPERR_PARAM;
     }
     ibuf += sizeof(sessid);
-    
+
     if (uam_afpserver_option(obj, UAM_OPTION_CLIENTNAME,
 			     (void *) &hostname, NULL) < 0)
 	{
@@ -449,20 +451,20 @@ static int pam_logincont(void *obj, struct passwd **uam_pwd,
 	hostname = NULL;
 	}
 
-    CAST_cbc_encrypt((unsigned char *)ibuf, (unsigned char *)rbuf, CRYPT2BUFLEN, &castkey,
+    CAST_cbc_encrypt(ibuf, rbuf, CRYPT2BUFLEN, &castkey,
 		     msg3_iv, CAST_DECRYPT);
     memset(&castkey, 0, sizeof(castkey));
 
     /* check to make sure that the random number is the same. we
      * get sent back an incremented random number. */
-    if (!(bn1 = BN_bin2bn((unsigned char *)rbuf, KEYSIZE, NULL)))
+    if (!(bn1 = BN_bin2bn(rbuf, KEYSIZE, NULL)))
       return AFPERR_PARAM;
 
     if (!(bn2 = BN_bin2bn(randbuf, sizeof(randbuf), NULL))) {
       BN_free(bn1);
       return AFPERR_PARAM;
     }
-      
+
     /* zero out the random number */
     memset(rbuf, 0, sizeof(randbuf));
     memset(randbuf, 0, sizeof(randbuf));
@@ -490,8 +492,8 @@ static int pam_logincont(void *obj, struct passwd **uam_pwd,
     PAM_password = rbuf;
 
     err = AFPERR_NOTAUTH;
-    PAM_error = pam_start("netatalk", PAM_username, &PAM_conversation,
-			  &pamh);
+    PAM_error = pam_start("netatalk", (const char *)PAM_username,
+			&PAM_conversation, &pamh);
     if (PAM_error != PAM_SUCCESS) {
     /* Log Entry */
            LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM: PAM_Error: %s",
@@ -505,14 +507,14 @@ static int pam_logincont(void *obj, struct passwd **uam_pwd,
     pam_set_item(pamh, PAM_RHOST, hostname);
     PAM_error = pam_authenticate(pamh,0);
     if (PAM_error != PAM_SUCCESS) {
-      if (PAM_error == PAM_MAXTRIES) 
+      if (PAM_error == PAM_MAXTRIES)
 	err = AFPERR_PWDEXPR;
     /* Log Entry */
            LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM: PAM_Error: %s",
 		  pam_strerror(pamh, PAM_error));
     /* Log Entry */
       goto logincont_err;
-    }      
+    }
 
     PAM_error = pam_acct_mgmt(pamh, 0);
     if (PAM_error != PAM_SUCCESS ) {
@@ -523,7 +525,7 @@ static int pam_logincont(void *obj, struct passwd **uam_pwd,
       if (PAM_error == PAM_NEW_AUTHTOK_REQD)	/* password expired */
 	err = AFPERR_PWDEXPR;
 #ifdef PAM_AUTHTOKEN_REQD
-      else if (PAM_error == PAM_AUTHTOKEN_REQD) 
+      else if (PAM_error == PAM_AUTHTOKEN_REQD)
 	err = AFPERR_PWDCHNG;
 #endif
       else
@@ -577,9 +579,9 @@ static void pam_logout(void) {
 
 /* change pw for dhx needs a couple passes to get everything all
  * right. basically, it's like the login/logincont sequence */
-static int pam_changepw(void *obj, char *username,
-			struct passwd *pwd _U_, char *ibuf, size_t ibuflen,
-			char *rbuf, size_t *rbuflen)
+static int pam_changepw(void *obj, unsigned char *username,
+			const struct passwd *pwd _U_, unsigned char *ibuf,
+			size_t ibuflen, unsigned char *rbuf, size_t *rbuflen)
 {
     BIGNUM *bn1, *bn2, *bn3;
 
@@ -596,7 +598,7 @@ static int pam_changepw(void *obj, char *username,
     /* grab the id */
     memcpy(&sessid, ibuf, sizeof(sessid));
     ibuf += sizeof(sessid);
-    
+
     if (!sessid) {  /* no sessid -> initialization phase */
       PAM_username = username;
       ibuflen -= sizeof(sessid);
@@ -626,13 +628,13 @@ static int pam_changepw(void *obj, char *username,
     }
 
     /* grab the client's nonce, old password, and new password. */
-    CAST_cbc_encrypt((unsigned char *)ibuf, (unsigned char *)ibuf, CHANGEPWBUFLEN, &castkey,
+    CAST_cbc_encrypt(ibuf, ibuf, CHANGEPWBUFLEN, &castkey,
 		     msg3_iv, CAST_DECRYPT);
     memset(&castkey, 0, sizeof(castkey));
 
     /* check to make sure that the random number is the same. we
      * get sent back an incremented random number. */
-    if (!(bn1 = BN_bin2bn((unsigned char *)ibuf, KEYSIZE, NULL))) {
+    if (!(bn1 = BN_bin2bn(ibuf, KEYSIZE, NULL))) {
     /* Log Entry */
            LOG(log_info, logtype_uams, "uams_dhx_pam.c :PAM: Random Number Not the same or not incremented-- %s",
 		  strerror(errno));
@@ -648,7 +650,7 @@ static int pam_changepw(void *obj, char *username,
     /* Log Entry */
       return AFPERR_PARAM;
     }
-      
+
     /* zero out the random number */
     memset(rbuf, 0, sizeof(randbuf));
     memset(randbuf, 0, sizeof(randbuf));
@@ -688,7 +690,7 @@ static int pam_changepw(void *obj, char *username,
     ibuf[PASSWDLEN + PASSWDLEN] = '\0';
     PAM_password = ibuf + PASSWDLEN;
 
-    PAM_error = pam_start("netatalk", username, &PAM_conversation,
+    PAM_error = pam_start("netatalk", (char *)username, &PAM_conversation,
 			  &lpamh);
     if (PAM_error != PAM_SUCCESS) {
     /* Log Entry */
@@ -735,11 +737,11 @@ static int pam_changepw(void *obj, char *username,
 
 static int uam_setup(void *obj, const char *path)
 {
-  if (uam_register(UAM_SERVER_LOGIN_EXT, path, "DHCAST128", pam_login, 
+  if (uam_register(UAM_SERVER_LOGIN_EXT, path, "DHCAST128", pam_login,
 		   pam_logincont, pam_logout, pam_login_ext) < 0)
     return -1;
 
-  if (uam_register(UAM_SERVER_CHANGEPW, path, "DHCAST128", 
+  if (uam_register(UAM_SERVER_CHANGEPW, path, "DHCAST128",
 		   pam_changepw) < 0) {
     uam_unregister(UAM_SERVER_LOGIN, "DHCAST128");
     return -1;
@@ -771,4 +773,3 @@ UAM_MODULE_EXPORT struct uam_export uams_dhx_pam = {
 };
 
 #endif /* USE_PAM && UAM_DHX */
-
