@@ -8,39 +8,42 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <atalk/standards.h>
-
+#include <arpa/inet.h>
+#include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/time.h>
+#include <time.h>
 #include <unistd.h>
+
 #ifdef HAVE_CRYPT_H
 #include <crypt.h>
 #endif /* ! HAVE_CRYPT_H */
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#endif
-#ifdef HAVE_TIME_H
-#include <time.h>
-#endif
-#include <pwd.h>
+
 #ifdef SHADOWPW
 #include <shadow.h>
 #endif /* SHADOWPW */
-#if defined(GNUTLS_DHX)
-#include <gnutls/openssl.h>
+
+#if defined(EMBEDDED_SSL) || defined(WOLFSSL_DHX)
+#if defined(WOLFSSL_DHX)
+#include <wolfssl/options.h>
+#endif
+#include <openssl/cast.h>
+#include <wolfssl/openssl/bn.h>
+#include <wolfssl/openssl/dh.h>
+#include <wolfssl/openssl/err.h>
+#include <wolfssl/openssl/ssl.h>
 #elif defined(OPENSSL_DHX)
 #include <openssl/bn.h>
 #include <openssl/dh.h>
 #include <openssl/cast.h>
-#else /* OPENSSL_DHX */
-#include <bn.h>
-#include <dh.h>
-#include <cast.h>
-#endif /* OPENSSL_DHX */
+#include "openssl_compat.h"
+#endif /* EMBEDDED_SSL */
 
-#include <atalk/logger.h>
 #include <atalk/afp.h>
+#include <atalk/logger.h>
+#include <atalk/standards.h>
 #include <atalk/uam.h>
 
 #define KEYSIZE 16
@@ -55,8 +58,7 @@
 /* the secret key */
 static CAST_KEY castkey;
 static struct passwd *dhxpwd;
-static u_int8_t randbuf[16];
-
+static uint8_t randbuf[16];
 
 /* dhx passwd */
 static int pwd_login(void *obj, char *username, int ulen, struct passwd **uam_pwd _U_,
@@ -64,26 +66,23 @@ static int pwd_login(void *obj, char *username, int ulen, struct passwd **uam_pw
 			char *rbuf, size_t *rbuflen)
 {
     unsigned char iv[] = "CJalbert";
-    u_int8_t p[] = {0xBA, 0x28, 0x73, 0xDF, 0xB0, 0x60, 0x57, 0xD4,
+    uint8_t p[] = {0xBA, 0x28, 0x73, 0xDF, 0xB0, 0x60, 0x57, 0xD4,
 		    0x3F, 0x20, 0x24, 0x74, 0x4C, 0xEE, 0xE7, 0x5B };
-    u_int8_t g = 0x07;
+    uint8_t g = 0x07;
 #ifdef SHADOWPW
     struct spwd *sp;
 #endif /* SHADOWPW */
     BIGNUM *bn, *gbn, *pbn;
     const BIGNUM *pub_key;
-    u_int16_t sessid;
+    uint16_t sessid;
     size_t i;
     DH *dh;
-
-
     *rbuflen = 0;
 
-
     if (( dhxpwd = uam_getname(obj, username, ulen)) == NULL ) {
         return AFPERR_NOTAUTH;
     }
-    
+
     LOG(log_info, logtype_uams, "dhx login: %s", username);
     if (uam_checkuser(dhxpwd) < 0)
       return AFPERR_NOTAUTH;
@@ -141,18 +140,18 @@ static int pwd_login(void *obj, char *username, int ulen, struct passwd **uam_pw
 
     /* figure out the key. use rbuf as a temporary buffer. */
     i = DH_compute_key((unsigned char *)rbuf, bn, dh);
-    
+
     /* set the key */
     CAST_set_key(&castkey, i, (unsigned char *)rbuf);
-    
+
     /* session id. it's just a hashed version of the object pointer. */
     sessid = dhxhash(obj);
     memcpy(rbuf, &sessid, sizeof(sessid));
     rbuf += sizeof(sessid);
     *rbuflen += sizeof(sessid);
-    
+
     /* send our public key */
-    BN_bn2bin(pub_key, (unsigned char *)rbuf); 
+    BN_bn2bin(pub_key, (unsigned char *)rbuf);
     rbuf += KEYSIZE;
     *rbuflen += KEYSIZE;
 
@@ -162,17 +161,17 @@ static int pwd_login(void *obj, char *username, int ulen, struct passwd **uam_pw
 			     &i) < 0) {
       *rbuflen = 0;
       goto passwd_fail;
-    }    
+    }
     memcpy(rbuf, &randbuf, sizeof(randbuf));
 
 #if 0
     /* get the signature. it's always 16 bytes. */
-    if (uam_afpserver_option(obj, UAM_OPTION_SIGNATURE, 
+    if (uam_afpserver_option(obj, UAM_OPTION_SIGNATURE,
 			     (void *) &name, NULL) < 0) {
       *rbuflen = 0;
       goto passwd_fail;
     }
-    memcpy(rbuf + KEYSIZE, name, KEYSIZE); 
+    memcpy(rbuf + KEYSIZE, name, KEYSIZE);
 #else /* 0 */
     memset(rbuf + KEYSIZE, 0, KEYSIZE);
 #endif /* 0 */
@@ -223,10 +222,10 @@ static int passwd_login(void *obj, struct passwd **uam_pwd,
 	ibuflen--;
     }
     return (pwd_login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
-    
+
 }
 
-/* cleartxt login ext 
+/* cleartxt login ext
  * uname format :
     byte      3
     2 bytes   len (network order)
@@ -238,10 +237,10 @@ static int passwd_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
 {
     char       *username;
     size_t     len, ulen;
-    u_int16_t  temp16;
+    uint16_t  temp16;
 
     *rbuflen = 0;
-    
+
     if (uam_afpserver_option(obj, UAM_OPTION_USERNAME,
 			     (void *) &username, &ulen) < 0)
 	return AFPERR_MISC;
@@ -260,7 +259,7 @@ static int passwd_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
 }
 			
 static int passwd_logincont(void *obj, struct passwd **uam_pwd,
-			    char *ibuf, size_t ibuflen _U_, 
+			    char *ibuf, size_t ibuflen _U_,
 			    char *rbuf, size_t *rbuflen)
 {
 #ifdef SHADOWPW
@@ -268,7 +267,7 @@ static int passwd_logincont(void *obj, struct passwd **uam_pwd,
 #endif /* SHADOWPW */
     unsigned char iv[] = "LWallace";
     BIGNUM *bn1, *bn2, *bn3;
-    u_int16_t sessid;
+    uint16_t sessid;
     char *p;
     int err = AFPERR_NOTAUTH;
 
@@ -279,11 +278,11 @@ static int passwd_logincont(void *obj, struct passwd **uam_pwd,
     if (sessid != dhxhash(obj))
       return AFPERR_PARAM;
     ibuf += sizeof(sessid);
-   
+
     /* use rbuf as scratch space */
     CAST_cbc_encrypt((unsigned char *)ibuf, (unsigned char *)rbuf, CRYPT2BUFLEN, &castkey,
 		     iv, CAST_DECRYPT);
-    
+
     /* check to make sure that the random number is the same. we
      * get sent back an incremented random number. */
     if (!(bn1 = BN_bin2bn((unsigned char *)rbuf, KEYSIZE, NULL)))
@@ -293,7 +292,7 @@ static int passwd_logincont(void *obj, struct passwd **uam_pwd,
       BN_free(bn1);
       return AFPERR_PARAM;
     }
-      
+
     /* zero out the random number */
     memset(rbuf, 0, sizeof(randbuf));
     memset(randbuf, 0, sizeof(randbuf));
@@ -345,7 +344,7 @@ static int passwd_logincont(void *obj, struct passwd **uam_pwd,
 }
 
 
-static int uam_setup(const char *path)
+static int uam_setup(void *obj, const char *path)
 {
   if (uam_register(UAM_SERVER_LOGIN_EXT, path, "DHCAST128",
 		   passwd_login, passwd_logincont, NULL, passwd_login_ext) < 0)
